package com.wefanbot.winbot;


import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.File;

public class Frame extends JFrame {

    private static final Logger log = LoggerFactory.getLogger(Frame.class);


    /**
     * 窗口宽度
     */
    int WIDTH;

    /**
     * 窗口高度
     */
    int HEIGHT;


    /**
     * 菜单栏
     */
    private JMenuBar menuBar;

    /**
     * 菜单栏的高度
     */
    int menuBarHeight = 60;


    public static File excelSource;
    public static File imgDir;

    /**
     * 操作面板的宽度
     */
    private int panelOperatorWidth;
    private Panel panel;
    /**
     * 操作面板
     */
    private PanelOperator panelOperator;

    public Panel getPanel() {
        return panel;
    }

    public PanelOperator getPanelOperator() {
        return panelOperator;
    }

    public Frame(int width, int height, int panelOperatorWidth) {
        this.panelOperatorWidth = panelOperatorWidth;
        this.WIDTH = width;
        this.HEIGHT = height;

        this.setTitle("Winbot");
        this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        this.setSize(width, height);
        this.setResizable(false);
        this.setLayout(null);
        setLocationRelativeTo(null);
        this.initMenuBar();
        this.initPanel(width, height);
    }

    /**
     * 初始化面板
     * @param width
     * @param height
     */
    private void initPanel(int width, int height) {
        int panelWidth = width - panelOperatorWidth;
        int panelHeight = height - menuBarHeight;



        panel = new Panel();
        panel.setBounds(0, 0, panelWidth, panelHeight);

        panelOperator = new PanelOperator(panelWidth, 0, panelOperatorWidth, panelHeight, this);

        this.add(panelOperator);
        this.add(panel);

        this.setVisible(true);


    }
    /**
     * 初始化菜单
     */
    private void initMenuBar() {

        menuBar = new JMenuBar();
        JMenu menuFile = new JMenu("文件(F)");
        menuFile.setMnemonic('F');  //设置菜单的键盘操作方式是Alt + F键

        JMenuItem itemOpen, itemSave, itemSaveOther;
        itemOpen = new JMenuItem("选择Excel");
        itemSave = new JMenuItem("选择图片文件夹");
        itemSaveOther = new JMenuItem("另存为");
        menuFile.add(itemOpen);
        menuFile.addSeparator();
        menuFile.add(itemSave);
//        menuFile.add(itemSaveOther);
        menuBar.add(menuFile);

        //设置菜单项的键盘操作方式是Ctrl+O和Ctrl+S键
        KeyStroke Ctrl_cutKey = KeyStroke.getKeyStroke(KeyEvent.VK_O, InputEvent.CTRL_MASK);
        itemOpen.setAccelerator(Ctrl_cutKey);

        Ctrl_cutKey = KeyStroke.getKeyStroke(KeyEvent.VK_S, InputEvent.CTRL_MASK);
        itemSave.setAccelerator(Ctrl_cutKey);

        setJMenuBar(menuBar);

        itemOpen.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {

                JFileChooser jfc = new JFileChooser();
                jfc.setFileSelectionMode(JFileChooser.FILES_ONLY);
                jfc.showDialog(new JLabel(), "选择Excel");
                File file = jfc.getSelectedFile();

                if (file == null) {
                    return;
                }

                if (!file.exists()) {
                    JOptionPane.showMessageDialog(null, "文件不存在", "错误", JOptionPane.YES_NO_OPTION);
                    return;
                }

                String path = file.getAbsolutePath();
                if (!(path.endsWith(".csv") || path.endsWith(".xlsx") || path.endsWith(".xsx"))) {
                    JOptionPane.showMessageDialog(null, "不是xsx文件", "错误", JOptionPane.YES_NO_OPTION);
                    return;
                }

                excelSource = file;
                log.info("选择excel文件来源，{}", excelSource.getAbsolutePath());

            }
        });

        itemSave.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {

                JFileChooser jfc = new JFileChooser();
                jfc.setFileSelectionMode(JFileChooser.FILES_ONLY);
                jfc.showDialog(new JLabel(), "选择图片文件夹");
                File file = jfc.getSelectedFile();

                if (file == null) {
                    return;
                }

                if (!file.exists()) {
                    JOptionPane.showMessageDialog(null, "文件不存在", "错误", JOptionPane.YES_NO_OPTION);
                    return;
                }

                if (!file.isDirectory()) {
                    JOptionPane.showMessageDialog(null, "不是文件夹", "错误", JOptionPane.YES_NO_OPTION);
                    return;
                }

                imgDir = file;
                log.info("选择excel文件来源，{}", imgDir.getAbsolutePath());

            }
        });

    }


}
